.. _api:

=============
API Reference
=============

-------
Classes
-------

.. autosummary::
    :toctree: generated
    :caption: Functions
    :recursive:
    :template: autosummary/class.rst
    
    ortho.OrthogonalFunctions
